# Species-OT

[](
[![Downloads](https://static.pepy.tech/badge/scegot)](https://pepy.tech/project/speciesot)
)

Geometric inference of cross-species transcriptome correspondence using Gromov-Wasserstein optimal transport.

![fig.png](./docs/_static/fig.png)

## Installation

```sh
$ pip install speciesot
```

## Requirements

- Python3
- Apple Silicon or NVIDIA GPUs (recommended)

  Click [here](https://developer.apple.com/metal/jax/) to learn how to utilize Apple Silicon's GPUs (official documentation).

## Documentation

The tutorial is available [here](https://yuyatokuta.github.io/Species-OT/).

## Preprint

Please see the following paper:
[Y. Tokuta et al. Geometric inference of cross-species transcriptome correspondence using Gromov-Wasserstein optimal transport. bioRxiv](https://doi.org/)
